@@ -1,28 +1,36 @@
-#' @title **infer**ring **C**ell-**S**pecific gene regulatory **N**etwork
-#'
-#' @useDynLib inferCSN
+#' @title inferring cell-type specific gene regulatory network
 #'
 #' @md
-#' @param object The input data for *`inferCSN`*.
-#' @param penalty The type of regularization, default is *`L0`*.
-#' This can take either one of the following choices: *`L0`*, *`L0L1`*, and *`L0L2`*.
-#' For high-dimensional and sparse data, *`L0L2`* is more effective.
-#' @param cross_validation Logical value, default is *`FALSE`*, whether to use cross-validation.
-#' @param n_folds The number of folds for cross-validation, default is *`5`*.
-#' @param seed The random seed for cross-validation, default is *`1`*.
-#' @param subsampling_method The method to use for subsampling. Options are "sample", "pseudobulk" or "meta_cells".
-#' @param subsampling_ratio The percent of all samples used for \code{\link{fit_srm}}, default is *`1`*.
-#' @param r_squared_threshold Threshold of \eqn{R^2} coefficient, default is *`0`*.
+#' @param object The input data for `inferCSN`.
+#' @param penalty The type of regularization, default is `"L0"`.
+#' This can take either one of the following choices: `"L0"`, `"L0L1"`, and `"L0L2"`.
+#' For high-dimensional and sparse data, `"L0L2"` is more effective.
+#' @param cross_validation Whether to use cross-validation.
+#' Default is `FALSE`.
+#' @param n_folds The number of folds for cross-validation.
+#' Default is `5`.
+#' @param seed The random seed for cross-validation.
+#' Default is `1`.
+#' @param subsampling_method The method to use for subsampling.
+#' Options are `"sample"`, `"pseudobulk"` or `"meta_cells"`.
+#' @param subsampling_ratio The percent of all samples used for [fit_srm].
+#' Default is `1`.
+#' @param r_squared_threshold Threshold of \eqn{R^2} coefficient.
+#' Default is `0`.
 #' @param regulators The regulator genes for which to infer the regulatory network.
 #' @param targets The target genes for which to infer the regulatory network.
-#' Recommend setting this to a small fraction of min(n,p) (e.g. 0.05 * min(n,p)) as L0 regularization typically selects a small portion of non-zeros.
-#' @param cores The number of cores to use for parallelization with \code{\link[foreach]{foreach}}, default is *`1`*.
-#' @param verbose Logical value, default is *`TRUE`*, whether to print progress messages.
+#' @param cores The number of cores to use for parallelization with [foreach::foreach].
+#' Default is `1`.
+#' @param verbose Whether to print progress messages.
+#' Default is `TRUE`.
 #' @param ... Parameters for other methods.
 #'
 #' @docType methods
 #' @rdname inferCSN
-#' @return A data table of regulator-target regulatory relationships
+#' @return
+#' A data table of regulator-target regulatory relationships.
+#' The data table has the three columns: regulator, target, and weight.
+#'
 #' @export
 setGeneric(
   name = "inferCSN",
@@ -53,7 +61,7 @@ setGeneric(
 #' @export
 #'
 #' @examples
-#' data("example_matrix")
+#' data(example_matrix)
 #' network_table_1 <- inferCSN(
 #'   example_matrix
 #' )
@@ -116,7 +124,7 @@ setMethod(
                         cores = 1,
                         verbose = TRUE,
                         ...) {
-    log_message(
+    thisutils::log_message(
       "Running for <dense matrix>.",
       verbose = verbose
     )
@@ -156,9 +164,7 @@ setMethod(
     )
 
     names(targets) <- targets
-    cores <- .cores_detect(cores, length(targets))
-
-    network_table <- parallelize_fun(
+    network_table <- thisutils::parallelize_fun(
       x = targets,
       fun = function(x) {
         single_network(
@@ -168,9 +174,8 @@ setMethod(
           cross_validation = cross_validation,
           seed = seed,
           penalty = penalty,
-          n_folds = n_folds,
-          subsampling_ratio = subsampling_ratio,
           r_squared_threshold = r_squared_threshold,
+          n_folds = n_folds,
           verbose = verbose,
           ...
         )
@@ -181,7 +186,7 @@ setMethod(
       purrr::list_rbind() |>
       network_format(abs_weight = FALSE)
 
-    log_message(
+    thisutils::log_message(
       "Run done.",
       message_type = "success",
       verbose = verbose
@@ -196,7 +201,7 @@ setMethod(
 #'
 #' @examples
 #' \dontrun{
-#' data("example_matrix")
+#' data(example_matrix)
 #' network_table <- inferCSN(example_matrix)
 #' head(network_table)
 #'
@@ -251,7 +256,7 @@ setMethod(
                         cores = 1,
                         verbose = TRUE,
                         ...) {
-    log_message(
+    thisutils::log_message(
       "Running for <", class(object), ">.",
       verbose = verbose
     )
@@ -291,9 +296,7 @@ setMethod(
     )
 
     names(targets) <- targets
-    cores <- .cores_detect(cores, length(targets))
-
-    network_table <- parallelize_fun(
+    network_table <- thisutils::parallelize_fun(
       x = targets,
       fun = function(x) {
         single_network(
@@ -315,7 +318,7 @@ setMethod(
       purrr::list_rbind() |>
       network_format(abs_weight = FALSE)
 
-    log_message(
+    thisutils::log_message(
       "Run done.",
       message_type = "success",
       verbose = verbose
@@ -345,14 +348,14 @@ setMethod(
                         cores = 1,
                         verbose = TRUE,
                         ...) {
-    log_message(
+    thisutils::log_message(
       "convert the class type of the input data from <data.frame> to <matrix>.",
       message_type = "warning",
       verbose = verbose
     )
 
     inferCSN(
-      object = as_matrix(object),
+      object = thisutils::as_matrix(object),
       penalty = penalty,
       cross_validation = cross_validation,
       seed = seed,
